contexttools.get_context_mark_attached_to_component
===================================================

.. autofunction:: abjad.tools.contexttools.get_context_mark_attached_to_component.get_context_mark_attached_to_component
   :noindex:
